#
# spec file for package sushi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __requires_exclude typelib\\(LOKDocView\\)

Name:           sushi
Version:        45.0
Release:        2.1
Summary:        Quick Previewer for Nautilus
License:        SUSE-GPL-2.0-with-plugin-exception
Group:          Productivity/File utilities
URL:            https://www.gnome.org
Source0:        45/%{name}-%{version}.tar.zst
Source99:       sushi-rpmlintrc

BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(evince-document-3.0)
BuildRequires:  pkgconfig(evince-view-3.0)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(gjs-1.0) >= 1.38.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.29.14
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.9.6
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-audio-1.0)
BuildRequires:  pkgconfig(gstreamer-tag-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.13.2
BuildRequires:  pkgconfig(gtk+-wayland-3.0)
BuildRequires:  pkgconfig(gtk+-x11-3.0)
BuildRequires:  pkgconfig(gtksourceview-4) >= 4.0.3
BuildRequires:  pkgconfig(harfbuzz) >= 0.9.9
BuildRequires:  pkgconfig(webkit2gtk-4.1)
Supplements:    nautilus
Requires:       (typelib(LOKDocView) if libreoffice)
Requires:       typelib(WebKit2) = 4.1

%description
Sushi is a quick previewer for Nautilus, the GNOME desktop file manager.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-D wayland=enabled \
	-D X11=enabled \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%files
%license COPYING
%doc AUTHORS NEWS README.md
%{_bindir}/%{name}
%{_datadir}/dbus-1/services/org.gnome.NautilusPreviewer.service
%{_datadir}/metainfo/org.gnome.NautilusPreviewer.appdata.xml
%dir %{_datadir}/%{name}/gtksourceview-4
%dir %{_datadir}/%{name}/gtksourceview-4/styles
%{_datadir}/%{name}/gtksourceview-4/styles/builder-dark.style-scheme.xml
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/gir-1.0
%{_datadir}/%{name}/gir-1.0/Sushi-1.0.gir
%{_datadir}/%{name}/org.gnome.NautilusPreviewer.data.gresource
%{_datadir}/%{name}/org.gnome.NautilusPreviewer.src.gresource
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/girepository-1.0
%{_libdir}/%{name}/girepository-1.0/Sushi-1.0.typelib
%{_libdir}/%{name}/libsushi-1.0.so
%{_libexecdir}/org.gnome.NautilusPreviewer

%files lang -f %{name}.lang

%changelog
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Convert to source service for easier updating.
* Mon Sep 18 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + Updated translations.
* Fri Jul  7 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.alpha.2:
  + Fix build.
- Changes from version 45.alpha.1:
  + Fix translatable filename.
- Changes from version 45.alpha:
  + Fix window size with custom scale factor in x11.
  + Don't show window before renderer is ready.
  + Allow keyboard copy shortcuts for evince and text viewers.
  + Fix crash when switching between audio files.
  + Fix coverart download.
  + Add ParentHandle dbus property.
  + Add development profile.
* Tue May 30 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.2:
  + Fix loading certain documents in evince.
  + Updated translations.
* Fri Sep 16 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Another stable Sushi release.
- Changes from version 43.rc:
  + Make Webkit-4.1 a hard dependency.
* Fri Jul  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Enable web process (webkit) sandbox.
  + Use EvinceView.JobLoadGFile for loading documents.
  + Check for mimeTypes when populating list of viewers.
  + Allow right-clicks to show context menu for GtkSourceView.
  + Updated translations.
* Tue Apr  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.2:
  + Enable web process sandbox (webkitgtk).
* Fri Apr  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.1:
  + Enable web process (webkitgtk) sandbox.
* Sun Feb 13 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add typelib\\(LOKDocView\\) global requires exclude: We do not
  want to mandate libreoffice install just for the file preview
  funtion. If libreoffice is installed, the preview in will
  function as expected.
- Following the above, add (typelib(LOKDocView) if libreoffice)
  Requires: Pull in the needed libreoffice glue if libreoffice is
  installed.
- Pass explicit wayland=enabled and X11=enabled to meson, ensure we
  build support for both (we already have dependencies in place).
* Tue Sep 21 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + Drop libmusicbrainz dependency (use libsoup directly).
  + Account for scale-factor when estimating window size.
  + Build against webkit2gtk-4.1
  + Disable webkit sandboxing.
  + Updated translations.
- Drop pkgconfig(libmusicbrainz5) BuildRequires: No longer needed.
- Replace pkgconfig(webkit2gtk-4.0) with pkgconfig(webkit2gtk-4.1)
  BuildRequires following upstream changes.
* Fri Jun  4 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.1:
  + Account for scaling factor while estimating window size
* Thu Oct 22 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.38.0:
  + Fix build when Wayland is disabled.
  + Make X11 and Wayland configurable at build time.
  + Sync font-widget with gnome-font-viewer.
  + Fix various meson build issues.
  + Sandbox webkitgtk.
  + Fix crash caused by the lack of getters for viewers'
    properties.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Sep 10 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + Add support for moving Nautilus selection with arrow keys.
  + Add support for parenting the window on Wayland.
  + Use builder-dark style for text/source viewer.
  + Add localization for appdata file.
* Mon Sep  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.33.90:
  + Add a command line launcher.
  + Fix viewer mimetype matching.
  + Load viewers from home directory.
  + Updated translations.
- Changes from version 3.33.4:
  + Add a native LibreofficeKit renderer.
  + Fix translation infrastructure regression.
  + Fix loading album cover art from Amazon.
  + Fix several glitches on HiDpi and fractional scaling displays.
  + Respect placement of close button preference.
  + Fix audio metadata tags retrieval.
  + Only load a single GstTagList copy.
  + Fix displaying audio tag content with markup characters.
  + Add an appdata file.
  + Properly letterbox album cover art.
  + Add a way to report loading errors in the main view.
  + Scale window size with display resolution.
- Changes from version 3.33.3:
  + Rewrite to use GTK directly, drop Clutter dependency.
  + Use GtkSourceView 4.
- Drop sushi-port-to-gtksourceview4.patch: Fixed upstream.
- Add meson BuildRequires and macros.
- Drop pkgconfig(clutter-1.0), pkgconfig(clutter-gst-3.0),
  pkgconfig(clutter-gtk-1.0), pkgconfig(clutter-x11-1.0) and
  pkgconfig(gstreamer-pbutils-1.0) BuildRequires following upstream
  changes.
- Add pkgconfig(epoxy), pkgconfig(gdk-pixbuf-2.0),
  pkgconfig(gio-unix-2.0), pkgconfig(gstreamer-audio-1.0),
  pkgconfig(gstreamer-video-1.0), pkgconfig(gtk+-wayland-3.0) and
  pkgconfig(gtk+-x11-3.0) BuildRequires following upstream
  changes.
- Add sushi-rpmlintrc, filter out needless warning about gir file.
- Drop libsushi-1_0-0 and typelib-1_0-Sushi-1_0 Obsoletes: No
  currently supported version of openSUSE should have these
  installed.
* Wed Jun 19 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Specify GtkSourceView 3.0 import version.
- Rebase sushi-port-to-gtksourceview4.patch, drop part now included
  in tarball.
* Tue Jun 18 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add sushi-port-to-gtksourceview4.patch: Port to gtksourceview4.
  Following this patch, replace pkgconfig(gtksourceview-3.0) with
  pkgconfig(gtksourceview-4) BuildRequires.
* Sun Mar 10 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Update DOAP file for GitLab move.
  + Explicitly hide minimize and maximize.
* Wed Jan  2 2019 bjorn.lie@gmail.com
- Update to version 3.31.2:
  + Port to meson build system.
  + Replace some deprecated API.
- Switch to meson build system, add meson BuildRequires and macros.
- Drop intltool BuildRequires, no longer used nor needed.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.30.0:
  + Fix miscellaneous warnings.
  + Rename service file to match owned bus name.
- Use autosetup and make_build macros.
* Tue Apr 24 2018 bjorn.lie@gmail.com
- Update to version 3.28.3:
  + Fix another LibreOffice to PDF conversion regression (hopefully
    for good this time).
* Fri Apr 20 2018 bjorn.lie@gmail.com
- Update to version 3.28.2:
  + Fix another LibreOffice to PDF conversion regression.
- Changes from version 3.28.1:
  + Fix LibreOffice to PDF conversion regression.
  + Add support for docx/pptx/xlsx MIME types.
- Changes from version 3.28.0:
  + Add support for GIF animations.
  + Use LibreOffice directly instead of unoconv.
  + Prefer LibreOffice from flatpak when installed.
- Drop unoconv BuildRequires and Recommends, following upstream
  changes.
- Replace gobject-introspection-devel with
  pkgconfig(gobject-introspection-1.0) BuildRequires.
- Drop no longer needed post(un) handling of
  glib2_gsettings_schema_post(un) and
  glib2_gsettings_schema_requires macro.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat May  6 2017 zaitor@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Thu Mar  2 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + Use correct icon when fullscreen.
  + Use upstream format.js code.
  + Specify GdkX11 import version.
  + Updated translations.
* Wed Aug 31 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Make sushi work under Wayland.
  + Fix builddir != srcdir builds.
  + Updated translations.
* Tue May 17 2016 zaitor@opensuse.org
- Update to version 3.20.0:
  + Link directly with harfbuzz.
  + Updated translations.
- Add pkgconfig(harfbuzz) BuildRequires and version it. New
  explicit dependency.
* Fri Mar  4 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + Port to ClutterGst 3.0.
  + Don't assume X.
  + Don't use deprecated style classes.
  + Port to GTask.
  + Fix toolbar spacing.
  + Resync font renderer from gnome-font-viewer.
- Drop sushi-port-to-clutter-gst-3.0.patch: fixed upstream.
- Remove libtool BuildRequires and call to autoreconf, as we no
  longer carry any patches.
* Sat Nov 14 2015 zaitor@opensuse.org
- Add sushi-port-to-clutter-gst-3.0.patch: Port to clutter-gst-3.0
  (bgo#756725). Also add libtool BuildRequires and pass autoreconf
  before configure as the patch touches the buildsystem.
- Following above port, replace pkgconfig(clutter-gst-2.0) for
  pkgconfig(clutter-gst-3.0) BuildRequires.
* Wed Sep 23 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Thu Jul 23 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + Apply embedded orientation to images.
  + Fix encoding problems when loading non utf-8 text files.
  + Do not crash when right clicking text previews.
  + Add a way to easily run under gdb.
  + Use regular GTK client side decorations.
  + Use GResource for auxiliary data.
  + Fix theming glitches after GTK update.
* Wed May 13 2015 zaitor@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Mon Apr  6 2015 dmueller@suse.com
- disable dependency on libreoffice for all non-x86 platforms
* Tue Mar 10 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Fix deadlock with recent clutter/clutter-gtk.
  + Don't require a parent window.
  + Port HTML viewer to WebKit2.
  + Fix margins in RTL.
  + Fix toolbar icons for RTL.
- Replace pkgconfig(webkitgtk-3.0) BuildRequires with
  pkgconfig(webkit2gtk-4.0): follow upstreams port to WebKit2.
* Sat Jan 31 2015 zaitor@opensuse.org
- Exclude unoconv BuildRequires on PPC arches as it is not
  available there.
* Thu Apr 24 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Thu Feb 20 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Fix compatibility with js24-based GJS.
  + Update for E4X removal.
  + Update FSF address.
- Drop sushi-e4x-removal.patch: Fixed upstream.
* Thu Feb 13 2014 dimstar@opensuse.org
- Add sushi-e4x-removal.patch: Stringify the xml definitions for
  E4X removal.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Make translations appear.
  + Some fixes for right-to-left languages.
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Fix a crash while loading PDF documents.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Call gtk_render_background when drawing SushiFontWidget.
  + Updated translations.
* Fri Feb  8 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Use a better padding for the font preview.
  + Remove custom CSS styling for SushiFontWidget.
  + Fix the build with automake 1.13.
* Mon Jan 14 2013 zaitor@opensuse.org
- Update to version 3.7.4:
  + Use PackageKit to install unoconv if not detected at runtime.
  + Drop gjs-dbus dependency.
  + Updated translations.
- Drop pkgconfig(gjs-dbus-1.0) BuildRequires, no longer needed.
* Tue Jan  8 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Use the single-include header for GtkSourceView.
  + Add some convenience functions to SushiFontWidget.
  + Use a better error message in SushiFontLoader.
  + Updated translations.
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Updated translations.
* Mon Oct  1 2012 dimstar@opensuse.org
- Add glib2_gsettings_schema_* handling to preamble, post and
  postun. Fixes bnc#782917.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Fix regression where double spacebar was required to activate
    preview from Nautilus.
  + Updated translations.
* Mon Sep 24 2012 cfarrell@suse.com
- license update: SUSE-GPL-2.0-with-plugin-exception
  sushi allows linking non free proprietary plugins
* Mon Sep 17 2012 zaitor@opensuse.org
- Update to version 3.5.92:
  + Updated translations.
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Port to libmusicbrainz5.
- Replace pkgconfig(libmusicbrainz4) BuildRequires with
  pkgconfig(libmusicbrainz5), following upstream.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Port to GStreamer 1.0
  + Fix OSD toolbar positioning for the audio viewer
- Replace pkgconfig() BuildRequires to follow the port to
  GStreamer 1.0:
  + Old: clutter-gst-1.0, gstreamer-0.10, gstreamer-pbutils-0.10
    and gstreamer-tag-0.10.
  + New: clutter-gst-2.0, gstreamer-1.0, gstreamer-pbutils-1.0
    and gstreamer-tag-1.0.
- Drop xz BuildRequires as it now comes for free in the build
  system.
* Wed Aug  8 2012 dimstar@opensuse.org
- Update to version 0.5.5:
  + Port to GDBus.
  + Port to GtkApplication.
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 0.5.4:
  + Unify folder and fallback file viewers.
  + Remove more of our custom theming.
  + Use a higher limit when querying the MusicBrainz service.
  + Don't hardcode /bin/bash in the launcher scripts.
- Add pkgconfig(freetype2) BuildRequires: new dependency.
* Mon Jun  4 2012 dimstar@opensuse.org
- Update to version 0.5.2:
  + Fall back to C locale when constructing the sample string
    before picking an entirely random-glyph string in the font
    widget.
  + Flip font widget orientation for RTL locales.
  + Always pick a valid size for fixed-size fonts in the font
    widget.
* Tue May 15 2012 dimstar@opensuse.org
- Update to version 0.5.1:
  + Use libmusicbrainz v4 API.
  + Add a preference to turn off client window decorations.
  + Fix vertical interline spacing in the font viewer.
  + Enable fullscreen for the font viewer.
  + Use OSD style class for toolbars.
  + Use GEdit GtkSourceView color scheme if available.
  + Don't install the private library in  the system libdir.
  + Use mime type list provided by Totem for gst and audio viewers.
- Replace pkgconfig(libmusicbrainz3) BuildRequires with
  pkgconfig(libmusicbrainz4), following upstreams change.
- Drop typelib-1_0-Sushi-1_0 and libsushi-1_0-0 subpackage: these
  are private libraries, not meant for others to be used. Obsolete
  those packages from the main package.
- Move unoconv Recommends from libsushi-1_0-0 to main package.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 0.4.1:
  + Fix a crash when fetching album cover art
  + Move the window to the current desktop workspace when shown
  + Avoid maximization and window snapping
  + Plug some memory leaks
* Tue Mar 27 2012 dimstar@opensuse.org
- Update to version 0.4.0:
  + Updated translations.
* Mon Mar 19 2012 dimstar@opensuse.org
- Update to version 0.3.92:
  + Properly center the window title in the allocated space.
  + Clear signal handlers when switching between viewer.
  + Updated translations.
* Mon Mar  5 2012 vuntz@opensuse.org
- Update to version 0.3.91:
  + Ellipsize title for long filenames
  + Use F11 as a keybinding for Fullscreen
  + Initialize X11 threads
  + Updated translations.
- Add pkgconfig(clutter-x11-1.0) BuildRequires: new upstream
  dependency.
* Mon Dec 19 2011 dimstar@opensuse.org
- Update to version 0.3.0:
  + Quote the file path before passing it to unoconv
  + Build with latest clutter-gtk
  + Updated translations.
- Drop sushi-quote-unoconv.patch: fixed upstream.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Wed Dec  7 2011 dimstar@opensuse.org
- Split typelib files into typelib-1_0-Sushi-1_0 subpackage.
* Wed Oct 19 2011 vuntz@opensuse.org
- Add sushi-quote-unoconv.patch: quote the file path before passing
  it to unoconv, to avoid issues when there is a space in the path.
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 0.2.1:
  + Fix OSD toolbar not appearing for text files previews.
  + Make sure the decoration title is centered with the close
    button.
  + Updated translations.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 0.2.0:
  + Updated translations.
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 0.1.92:
  + Implement cache for cover art
  + Improve documentation
  + Updated translations.
* Tue Aug 30 2011 vuntz@opensuse.org
- Update to version 0.1.90:
  + Add a Close() remote method
* Wed Jul 27 2011 vuntz@opensuse.org
- Update to version 0.0.5:
  + Use "document-open-symbolic" for run/open toolbar buttons
  + Require latest clutter-gtk to fix underallocations with GTK+
    3.1
  + Use g_format_size() instead of g_format_size_for_display()
  + Use the GTK+ dark theme
  + UTF8-validate the text before inserting it into the buffer
* Sat Jul  9 2011 vuntz@opensuse.org
- Update to version 0.0.4:
  + Relicense to GPLv2 with an exception clause to allow use
    non-free GStreamer plugins.
  + Fix some compilation warnings.
- Drop sushi-fix-warnings.patch: fixed upstream.
- Change license tag from GPLv3 to GPLv2+.
* Sun Jul  3 2011 vuntz@opensuse.org
- Initial package (version 0.0.3).
- sushi-fix-warnings.patch fixes build warnings that break the
  build.
